"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateAppFiles_1 = __importDefault(require("./generateAppFiles"));
describe('generateAppFiles', () => {
    const appConfig = {
        routes: {
            login: '/login',
            user: '/user/:id',
        },
        destinationDir: 'path/to/routes',
    };
    describe('general config', () => {
        it('should not generate any file if no destinationDir', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { destinationDir: undefined }));
            expect(files).toHaveLength(0);
        });
        it('should not generate Link if not needed', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { generateLinkComponent: false }));
            expect(files).toHaveLength(6);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('useRedirectLogin');
            expect(files[2].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/user');
            expect(files[3].filename).toEqual('patternUser');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('generateUrlUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('useRedirectUser');
            expect(files[5].extension).toEqual('.ts');
        });
    });
    describe('Default', () => {
        it('should generate files', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { routingType: 'Default' }));
            expect(files).toHaveLength(8);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('patternUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('generateUrlUser');
            expect(files[5].extension).toEqual('.ts');
            expect(files[6].destinationDir).toEqual('path/to/routes/user');
            expect(files[6].filename).toEqual('LinkUser');
            expect(files[6].extension).toEqual('.tsx');
            expect(files[7].destinationDir).toEqual('path/to/routes/user');
            expect(files[7].filename).toEqual('useRedirectUser');
            expect(files[7].extension).toEqual('.ts');
        });
    });
    describe('NextJS', () => {
        it('should generate files', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { routingType: 'NextJS' }));
            expect(files).toHaveLength(7);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[3].destinationDir).toEqual('path/to/routes/user');
            expect(files[3].filename).toEqual('patternUser');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('generateUrlUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('LinkUser');
            expect(files[5].extension).toEqual('.tsx');
            expect(files[6].destinationDir).toEqual('path/to/routes/user');
            expect(files[6].filename).toEqual('useParamsUser');
            expect(files[6].extension).toEqual('.ts');
        });
    });
    describe('ReactRouterV5', () => {
        it('should generate files', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { routingType: 'ReactRouterV5' }));
            expect(files).toHaveLength(9);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('patternUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('generateUrlUser');
            expect(files[5].extension).toEqual('.ts');
            expect(files[6].destinationDir).toEqual('path/to/routes/user');
            expect(files[6].filename).toEqual('LinkUser');
            expect(files[6].extension).toEqual('.tsx');
            expect(files[7].destinationDir).toEqual('path/to/routes/user');
            expect(files[7].filename).toEqual('useParamsUser');
            expect(files[7].extension).toEqual('.ts');
            expect(files[8].destinationDir).toEqual('path/to/routes/user');
            expect(files[8].filename).toEqual('useRedirectUser');
            expect(files[8].extension).toEqual('.ts');
        });
        it('should not generate useParams if not needed', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { routingType: 'ReactRouterV5', reactRouterV5LinkOptions: { generateUseParams: false } }));
            expect(files).toHaveLength(8);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('patternUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('generateUrlUser');
            expect(files[5].extension).toEqual('.ts');
            expect(files[6].destinationDir).toEqual('path/to/routes/user');
            expect(files[6].filename).toEqual('LinkUser');
            expect(files[6].extension).toEqual('.tsx');
            expect(files[7].destinationDir).toEqual('path/to/routes/user');
            expect(files[7].filename).toEqual('useRedirectUser');
            expect(files[7].extension).toEqual('.ts');
        });
        it('should not generate useRedirect if not needed', () => {
            const files = generateAppFiles_1.default('testApp', Object.assign(Object.assign({}, appConfig), { routingType: 'ReactRouterV5', reactRouterV5LinkOptions: { generateUseRedirect: false } }));
            expect(files).toHaveLength(7);
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[3].destinationDir).toEqual('path/to/routes/user');
            expect(files[3].filename).toEqual('patternUser');
            expect(files[3].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/user');
            expect(files[4].filename).toEqual('generateUrlUser');
            expect(files[4].extension).toEqual('.ts');
            expect(files[5].destinationDir).toEqual('path/to/routes/user');
            expect(files[5].filename).toEqual('LinkUser');
            expect(files[5].extension).toEqual('.tsx');
            expect(files[6].destinationDir).toEqual('path/to/routes/user');
            expect(files[6].filename).toEqual('useParamsUser');
            expect(files[6].extension).toEqual('.ts');
        });
    });
});
//# sourceMappingURL=generateAppFiles.test.js.map