"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateTemplateFiles_1 = __importDefault(require("./generateTemplateFiles"));
const config_1 = require("../config");
describe('generateTemplateFiles', () => {
    const params = {
        routeName: 'login',
        routePattern: '/login',
        routingType: config_1.RoutingType.Default,
        importGenerateUrl: {
            from: 'route-codegen',
            namedImports: [{ name: 'generateUrl' }],
        },
        destinationDir: 'path/to/routes',
        routeLinkOptions: {
            ReactRouterV5: {
                importLink: {
                    from: 'src/common/Link',
                    defaultImport: 'Link',
                    namedImports: [{ name: 'CustomLinkProps' }],
                },
                hrefProp: 'to',
                linkComponent: 'Link',
                linkProps: 'CustomLinkProps',
                generateLinkComponent: true,
                generateUseRedirect: true,
                generateUseParams: true,
            },
            Default: {
                hrefProp: 'href',
                linkComponent: 'a',
                inlineLinkProps: {
                    template: "type LinkProps = Omit<DefaultLinkProps, 'href'>;",
                    linkProps: 'LinkProps',
                },
                generateLinkComponent: true,
                generateUseRedirect: true,
            },
            NextJS: {
                importLink: {
                    from: 'src/NextJS/Link',
                    defaultImport: 'Link',
                    namedImports: [{ name: 'NextJSLinkProps' }],
                },
                linkComponent: 'Link',
                hrefProp: 'customHref',
                linkProps: 'NextJSLinkProps',
                generateLinkComponent: true,
                generateUseParams: true,
            },
        },
    };
    describe('Default', () => {
        it('should generate files', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routingType: config_1.RoutingType.Default }));
            expect(files).toHaveLength(4);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
        });
        it('should not generate Link if not needed', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routingType: config_1.RoutingType.Default, routeLinkOptions: Object.assign(Object.assign({}, params.routeLinkOptions), { Default: Object.assign(Object.assign({}, params.routeLinkOptions.Default), { generateLinkComponent: false }) }) }));
            expect(files).toHaveLength(3);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('useRedirectLogin');
            expect(files[2].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
        });
    });
    describe('ReactRouterV5', () => {
        it('should generate files when no dynamic path params', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routingType: config_1.RoutingType.ReactRouterV5 }));
            expect(files).toHaveLength(4);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
        });
        it('should generate files with dynamic path params', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routePattern: '/login/:id', routingType: config_1.RoutingType.ReactRouterV5 }));
            expect(files).toHaveLength(5);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useParamsLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
            expect(files[4].filename).toEqual('useRedirectLogin');
            expect(files[4].extension).toEqual('.ts');
            expect(files[4].destinationDir).toEqual('path/to/routes/login');
        });
        it('should not generate Link if not needed', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routePattern: '/login/:id', routingType: config_1.RoutingType.ReactRouterV5, routeLinkOptions: Object.assign(Object.assign({}, params.routeLinkOptions), { ReactRouterV5: Object.assign(Object.assign({}, params.routeLinkOptions.ReactRouterV5), { generateLinkComponent: false }) }) }));
            expect(files).toHaveLength(4);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('useParamsLogin');
            expect(files[2].extension).toEqual('.ts');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useRedirectLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
        });
    });
    describe('NextJS', () => {
        it('should generate files', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routingType: config_1.RoutingType.NextJS }));
            expect(files).toHaveLength(3);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
        });
        it('should generate files with dynamic path params', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routePattern: '/login/:id', routingType: config_1.RoutingType.NextJS }));
            expect(files).toHaveLength(4);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
            expect(files[2].filename).toEqual('LinkLogin');
            expect(files[2].extension).toEqual('.tsx');
            expect(files[2].destinationDir).toEqual('path/to/routes/login');
            expect(files[3].filename).toEqual('useParamsLogin');
            expect(files[3].extension).toEqual('.ts');
            expect(files[3].destinationDir).toEqual('path/to/routes/login');
        });
        it('should not generate Link if not needed', () => {
            const files = generateTemplateFiles_1.default(Object.assign(Object.assign({}, params), { routingType: config_1.RoutingType.NextJS, routeLinkOptions: Object.assign(Object.assign({}, params.routeLinkOptions), { NextJS: Object.assign(Object.assign({}, params.routeLinkOptions.NextJS), { generateLinkComponent: false }) }) }));
            expect(files).toHaveLength(2);
            expect(files[0].filename).toEqual('patternLogin');
            expect(files[0].extension).toEqual('.ts');
            expect(files[0].destinationDir).toEqual('path/to/routes/login');
            expect(files[1].filename).toEqual('generateUrlLogin');
            expect(files[1].extension).toEqual('.ts');
            expect(files[1].destinationDir).toEqual('path/to/routes/login');
        });
    });
});
//# sourceMappingURL=generateTemplateFiles.test.js.map