"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateLinkFileNextJS_1 = __importDefault(require("./generateLinkFileNextJS"));
describe('generateLinkFileNextJS', () => {
    const defaultParams = {
        importGenerateUrl: { namedImports: [{ name: 'generateUrl' }], from: 'route-codegen' },
        routeLinkOption: {
            importLink: {
                from: 'src/NextJS/Link',
                defaultImport: 'Link',
                namedImports: [{ name: 'NextJSLinkProps' }],
            },
            hrefProp: 'customHref',
            linkComponent: 'Link',
            linkProps: 'NextJSLinkProps',
            generateLinkComponent: true,
            generateUseParams: true,
        },
        routeName: 'Login',
        patternNamedExports: {
            filename: 'patternLogin',
            patternName: 'patternLogin',
            urlPartsInterfaceName: 'UrlPartsLogin',
            patternNameNextJS: 'patternNextJSLogin',
        },
        destinationDir: 'path/to/routes',
    };
    describe('NextJS', () => {
        it('should generate correctly if no path params', () => {
            const templateFile = generateLinkFileNextJS_1.default(Object.assign({}, defaultParams));
            expect(templateFile.filename).toBe('LinkLogin');
            expect(templateFile.extension).toBe('.tsx');
            expect(templateFile.destinationDir).toBe('path/to/routes');
            expect(templateFile.template).toContain(`import React from 'react'
  import {generateUrl,} from 'route-codegen'
  import Link, {NextJSLinkProps,} from 'src/NextJS/Link'
  import {patternLogin,UrlPartsLogin,patternNextJSLogin,} from './patternLogin'
  type LinkLoginProps = Omit<NextJSLinkProps, 'customHref'> & UrlPartsLogin
  const LinkLogin: React.FunctionComponent<LinkLoginProps> = ({  urlQuery, ...props }) => {
    const to = generateUrl(patternLogin, {}, urlQuery);
    return <Link {...props} customHref={patternNextJSLogin} as={to} />;
  }
  export default LinkLogin;`);
        });
        it('should generate correctly with path params', () => {
            const templateFile = generateLinkFileNextJS_1.default(Object.assign(Object.assign({}, defaultParams), { patternNamedExports: Object.assign(Object.assign({}, defaultParams.patternNamedExports), { pathParamsInterfaceName: 'PathParamsLogin', possiblePathParamsVariableName: 'possiblePathParamsLogin' }) }));
            expect(templateFile.filename).toBe('LinkLogin');
            expect(templateFile.extension).toBe('.tsx');
            expect(templateFile.destinationDir).toBe('path/to/routes');
            expect(templateFile.template).toContain(`import React from 'react'
  import {generateUrl,} from 'route-codegen'
  import Link, {NextJSLinkProps,} from 'src/NextJS/Link'
  import {patternLogin,UrlPartsLogin,patternNextJSLogin,possiblePathParamsLogin,} from './patternLogin'
  type LinkLoginProps = Omit<NextJSLinkProps, 'customHref'> & UrlPartsLogin
  const LinkLogin: React.FunctionComponent<LinkLoginProps> = ({ path, urlQuery, ...props }) => {
    const to = generateUrl(patternLogin, path, urlQuery);
    const href = possiblePathParamsLogin.filter((key) => !(key in path)).reduce((prevPattern, suppliedParam) => prevPattern.replace(\`/[${'${suppliedParam'}}]\`, ""), patternNextJSLogin);
    return <Link {...props} customHref={href} as={to} />;
  }
  export default LinkLogin;`);
        });
        it('should generate correctly with named component import', () => {
            const templateFile = generateLinkFileNextJS_1.default(Object.assign(Object.assign({}, defaultParams), { routeLinkOption: {
                    importLink: {
                        from: 'src/common/Link',
                        namedImports: [{ name: 'CustomLinkProps' }, { name: 'CustomLink', importAs: 'Link' }],
                    },
                    linkComponent: 'Link',
                    linkProps: 'CustomLinkProps',
                    hrefProp: 'to',
                    generateLinkComponent: true,
                    generateUseParams: true,
                } }));
            expect(templateFile.filename).toBe('LinkLogin');
            expect(templateFile.extension).toBe('.tsx');
            expect(templateFile.destinationDir).toBe('path/to/routes');
            expect(templateFile.template).toContain(`import React from 'react'
  import {generateUrl,} from 'route-codegen'
  import {CustomLinkProps,CustomLink as Link,} from 'src/common/Link'
  import {patternLogin,UrlPartsLogin,patternNextJSLogin,} from './patternLogin'
  type LinkLoginProps = Omit<CustomLinkProps, 'to'> & UrlPartsLogin
  const LinkLogin: React.FunctionComponent<LinkLoginProps> = ({  urlQuery, ...props }) => {
    const to = generateUrl(patternLogin, {}, urlQuery);
    return <Link {...props} to={patternNextJSLogin} as={to} />;
  }
  export default LinkLogin;`);
        });
        it('should throw error if no patternNameNextJS', () => {
            expect(() => generateLinkFileNextJS_1.default(Object.assign(Object.assign({}, defaultParams), { routeLinkOption: {
                    importLink: {
                        from: 'src/common/Link',
                        namedImports: [{ name: 'CustomLinkProps' }, { name: 'CustomLink', importAs: 'Link' }],
                    },
                    linkComponent: 'Link',
                    linkProps: 'CustomLinkProps',
                    hrefProp: 'to',
                    generateLinkComponent: true,
                    generateUseParams: true,
                }, patternNamedExports: Object.assign(Object.assign({}, defaultParams.patternNamedExports), { patternNameNextJS: undefined }) }))).toThrowError('[ERROR] Missing "patternNameNextJS". This is most likely a problem with route-codegen.');
        });
    });
});
//# sourceMappingURL=generateLinkFileNextJS.test.js.map