"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateUseRedirectReactRouterV5_1 = __importDefault(require("./generateUseRedirectReactRouterV5"));
describe('generateUseRedirectReactRouterV5', () => {
    it('should generate when there is no pathParams', () => {
        const templateFile = generateUseRedirectReactRouterV5_1.default({
            routeName: 'Login',
            patternNamedExports: {
                filename: 'patternLogin',
                patternName: 'patternLogin',
                urlPartsInterfaceName: 'UrlPartsLogin',
            },
            destinationDir: 'path/to/routes',
            importGenerateUrl: {
                from: 'route-codegen',
                namedImports: [{ name: 'generateUrl' }],
            },
        });
        expect(templateFile.filename).toBe('useRedirectLogin');
        expect(templateFile.extension).toBe('.ts');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template).toContain(`const useRedirectLogin = ( urlParts: UrlPartsLogin ): (() => void) => {
    const history = useHistory();
    const to = generateUrl(patternLogin, {}, urlParts.urlQuery);
    return () => history.push(to);
  }`);
    });
    it('should generate when there is pathParams', () => {
        const templateFile = generateUseRedirectReactRouterV5_1.default({
            routeName: 'UserInfo',
            patternNamedExports: {
                filename: 'patternUserInfo',
                patternName: 'patternUserInfo',
                urlPartsInterfaceName: 'UrlPartsUserInfo',
                pathParamsInterfaceName: 'PathParamsUserInfo',
            },
            destinationDir: 'path/to/routes',
            importGenerateUrl: {
                from: 'route-codegen',
                namedImports: [{ name: 'generateUrl' }],
            },
        });
        expect(templateFile.filename).toBe('useRedirectUserInfo');
        expect(templateFile.extension).toBe('.ts');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template)
            .toContain(`const useRedirectUserInfo = ( urlParts: UrlPartsUserInfo ): (() => void) => {
    const history = useHistory();
    const to = generateUrl(patternUserInfo, urlParts.path, urlParts.urlQuery);
    return () => history.push(to);
  }`);
    });
});
//# sourceMappingURL=generateUseRedirectReactRouterV5.test.js.map