"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateExternalRoutesConfig_1 = __importDefault(require("./generateExternalRoutesConfig"));
const config_1 = require("../config");
describe('generateExternalRoutesConfig', () => {
    it('should generate external app route objects correctly', () => {
        const apps = {
            main: {
                routes: {
                    login: '/app/login',
                    signup: '/app/signup',
                },
                destinationDir: 'main/src/routes',
                routingType: config_1.RoutingType.ReactRouterV5,
            },
            seo: {
                routes: {
                    home: '/',
                    about: '/about',
                    users: '/:id/:subview(profile|pictures)',
                },
                destinationDir: 'seo/src/routes',
                routingType: config_1.RoutingType.NextJS,
            },
            legacy: {
                routes: {
                    legacyBooks: '/legacy/books',
                },
            },
        };
        const externalRoutes = generateExternalRoutesConfig_1.default(apps);
        expect(externalRoutes).toStrictEqual({
            main: {
                routes: {
                    home: '/',
                    about: '/about',
                    users: '/:id/:subview(profile|pictures)',
                    legacyBooks: '/legacy/books',
                },
                destinationDir: 'main/src/routes',
                routingType: config_1.RoutingType.Default,
            },
            seo: {
                routes: {
                    login: '/app/login',
                    signup: '/app/signup',
                    legacyBooks: '/legacy/books',
                },
                destinationDir: 'seo/src/routes',
                routingType: config_1.RoutingType.Default,
            },
            legacy: {
                routes: {
                    login: '/app/login',
                    signup: '/app/signup',
                    home: '/',
                    about: '/about',
                    users: '/:id/:subview(profile|pictures)',
                },
                routingType: config_1.RoutingType.Default,
            },
        });
    });
});
//# sourceMappingURL=generateExternalRoutesConfig.test.js.map